"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const electron_1 = require("electron");
const eventType_1 = require("../lib/eventType");
const locale_1 = require("../locale/locale");
const config_1 = require("../settings/config");
const dialog = electron_1.dialog || electron_1.remote.dialog;
class AutomatedSingleSignOn {
    onResponseReceived(event) {
        return __awaiter(this, void 0, void 0, function* () {
            if (event.detail.reachedMaximumAccounts) {
                yield this.showError();
            }
        });
    }
    showError() {
        return __awaiter(this, void 0, void 0, function* () {
            let detail = locale_1.getText('wrapperAddAccountErrorMessagePlural');
            let message = locale_1.getText('wrapperAddAccountErrorTitlePlural');
            if (config_1.config.maximumAccounts === 1) {
                detail = locale_1.getText('wrapperAddAccountErrorMessageSingular');
                message = locale_1.getText('wrapperAddAccountErrorTitleSingular');
            }
            yield dialog.showMessageBox({
                detail,
                message,
                type: 'warning',
            });
        });
    }
    start(ssoCode) {
        return __awaiter(this, void 0, void 0, function* () {
            window.addEventListener(eventType_1.EVENT_TYPE.ACTION.CREATE_SSO_ACCOUNT_RESPONSE, (event) => __awaiter(this, void 0, void 0, function* () {
                if (event.detail) {
                    yield this.onResponseReceived(event);
                }
            }), {
                once: true,
            });
            window.dispatchEvent(new CustomEvent(eventType_1.EVENT_TYPE.ACTION.CREATE_SSO_ACCOUNT, {
                detail: {
                    code: ssoCode,
                },
            }));
        });
    }
}
exports.AutomatedSingleSignOn = AutomatedSingleSignOn;
//# sourceMappingURL=AutomatedSingleSignOn.js.map